Floating point error handling
*****************************

.. currentmodule:: numpy

Setting and getting error handling
----------------------------------

.. autosummary::
   :toctree: generated/

   seterr
   geterr
   seterrcall
   geterrcall
   errstate

Internal functions
------------------

.. autosummary::
   :toctree: generated/

   seterrobj
   geterrobj
